@@ -24,13 +24,12 @@ Authors:
 import os
 import tempfile
 import datetime
-import sys
 
 # if we have the optional module pyxarf, we can define more methods
 try:
     import pyxarf
 except ModuleNotFoundError:
-    pass
+    pyxarf = None
 
 from intelmqmail.db import load_events, new_ticket_number, mark_as_sent
 from intelmqmail.templates import read_template
@@ -175,7 +174,7 @@ class ScriptContext:
 
     def notification_interval_exceeded(self):
         """Return whether the notification interval has been exceeded.
-        This method looks at the directive atttributes last_sent and
+        This method looks at the directive attributes last_sent and
         notification_interval and returns whether more time than the
         notification_interval has passed since the last_sent time. A
         last_sent time of None, indicating that no similar notification
@@ -184,8 +183,8 @@ class ScriptContext:
         """
         last_sent = self.directive.last_sent
         notification_interval = self.directive.notification_interval
-        return (last_sent is None
-                or (last_sent + notification_interval < self.now))
+        return (last_sent is None or
+                (last_sent + notification_interval < self.now))
 
     def age_of_newest_directive(self):
         """Return the age of the newest directive in the group.
@@ -209,7 +208,7 @@ class ScriptContext:
         None.
         """
         time_observation = self.directive.get_aggregation_item(
-                "time.observation")
+            "time.observation")
         if time_observation is not None:
             return self.now - parse_timestamp(time_observation)
 
@@ -225,6 +224,7 @@ class ScriptContext:
         template_name = ''
         try:
             template_name = self.directive.template_name
+            print('Found template name', template_name)
             return read_template(self.config["template_dir"], template_name)
         except Exception as e:
             raise InvalidTemplate(template_name) from e
@@ -249,7 +249,7 @@ class ScriptContext:
         criteria, these are also available. Which these are precisely
         depends on the directives, but a common case is to aggregate
         notifications for events that share some information, so if the
-        directives specify aggregation by source.asn, this substition is
+        directives specify aggregation by source.asn, this substitution is
         also available.
 
         Args:
@@ -307,7 +307,7 @@ class ScriptContext:
                            attachments=attachments, gpgme_ctx=self.gpgme_ctx)
         return [EmailNotification(self.directive, mail, ticket)]
 
-    if "pyxarf" in sys.modules:
+    if pyxarf:
       def mail_format_as_xarf(self, xarf_schema): # noqa
         """Create Messages in X-Arf Format
 
@@ -372,7 +372,7 @@ class ScriptContext:
 
         return returnlist_notifications
 
-    if "pyxarf" in sys.modules:
+    if pyxarf:
       def create_xarf_mail(self, subject, body, xarf_object): # noqa
         """
 
